@@ -10,11 +10,11 @@ Usage::
     client: AmplifyBackendClient = boto3.client("amplifybackend")
     ```
 """
-import sys
 from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_amplifybackend.literals import ListBackendJobsPaginatorName
 from mypy_boto3_amplifybackend.paginator import ListBackendJobsPaginator
 from mypy_boto3_amplifybackend.type_defs import (
     BackendAPIResourceConfigTypeDef,
@@ -47,12 +47,6 @@ from mypy_boto3_amplifybackend.type_defs import (
     UpdateBackendJobResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("AmplifyBackendClient",)
 
 
@@ -74,7 +68,7 @@ class Exceptions:
 
 class AmplifyBackendClient:
     """
-    [AmplifyBackend.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client)
+    [AmplifyBackend.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client)
     """
 
     meta: ClientMeta
@@ -82,14 +76,14 @@ class AmplifyBackendClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.can_paginate)
         """
 
     def clone_backend(
         self, AppId: str, BackendEnvironmentName: str, TargetEnvironmentName: str
     ) -> CloneBackendResponseTypeDef:
         """
-        [Client.clone_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.clone_backend)
+        [Client.clone_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.clone_backend)
         """
 
     def create_backend(
@@ -101,7 +95,7 @@ class AmplifyBackendClient:
         ResourceName: str = None,
     ) -> CreateBackendResponseTypeDef:
         """
-        [Client.create_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend)
+        [Client.create_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend)
         """
 
     def create_backend_api(
@@ -112,7 +106,7 @@ class AmplifyBackendClient:
         ResourceName: str,
     ) -> CreateBackendAPIResponseTypeDef:
         """
-        [Client.create_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_api)
+        [Client.create_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_api)
         """
 
     def create_backend_auth(
@@ -123,26 +117,26 @@ class AmplifyBackendClient:
         ResourceName: str,
     ) -> CreateBackendAuthResponseTypeDef:
         """
-        [Client.create_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_auth)
+        [Client.create_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_auth)
         """
 
     def create_backend_config(
         self, AppId: str, BackendManagerAppId: str = None
     ) -> CreateBackendConfigResponseTypeDef:
         """
-        [Client.create_backend_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_config)
+        [Client.create_backend_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_config)
         """
 
     def create_token(self, AppId: str) -> CreateTokenResponseTypeDef:
         """
-        [Client.create_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.create_token)
+        [Client.create_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.create_token)
         """
 
     def delete_backend(
         self, AppId: str, BackendEnvironmentName: str
     ) -> DeleteBackendResponseTypeDef:
         """
-        [Client.delete_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend)
+        [Client.delete_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend)
         """
 
     def delete_backend_api(
@@ -153,26 +147,26 @@ class AmplifyBackendClient:
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None,
     ) -> DeleteBackendAPIResponseTypeDef:
         """
-        [Client.delete_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_api)
+        [Client.delete_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_api)
         """
 
     def delete_backend_auth(
         self, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> DeleteBackendAuthResponseTypeDef:
         """
-        [Client.delete_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_auth)
+        [Client.delete_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_auth)
         """
 
     def delete_token(self, AppId: str, SessionId: str) -> DeleteTokenResponseTypeDef:
         """
-        [Client.delete_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_token)
+        [Client.delete_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_token)
         """
 
     def generate_backend_api_models(
         self, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> GenerateBackendAPIModelsResponseTypeDef:
         """
-        [Client.generate_backend_api_models documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_backend_api_models)
+        [Client.generate_backend_api_models documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_backend_api_models)
         """
 
     def generate_presigned_url(
@@ -183,14 +177,14 @@ class AmplifyBackendClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_presigned_url)
         """
 
     def get_backend(
         self, AppId: str, BackendEnvironmentName: str = None
     ) -> GetBackendResponseTypeDef:
         """
-        [Client.get_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend)
+        [Client.get_backend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend)
         """
 
     def get_backend_api(
@@ -201,33 +195,33 @@ class AmplifyBackendClient:
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None,
     ) -> GetBackendAPIResponseTypeDef:
         """
-        [Client.get_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api)
+        [Client.get_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api)
         """
 
     def get_backend_api_models(
         self, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> GetBackendAPIModelsResponseTypeDef:
         """
-        [Client.get_backend_api_models documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api_models)
+        [Client.get_backend_api_models documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api_models)
         """
 
     def get_backend_auth(
         self, AppId: str, BackendEnvironmentName: str, ResourceName: str
     ) -> GetBackendAuthResponseTypeDef:
         """
-        [Client.get_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_auth)
+        [Client.get_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_auth)
         """
 
     def get_backend_job(
         self, AppId: str, BackendEnvironmentName: str, JobId: str
     ) -> GetBackendJobResponseTypeDef:
         """
-        [Client.get_backend_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_job)
+        [Client.get_backend_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_job)
         """
 
     def get_token(self, AppId: str, SessionId: str) -> GetTokenResponseTypeDef:
         """
-        [Client.get_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.get_token)
+        [Client.get_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.get_token)
         """
 
     def list_backend_jobs(
@@ -241,19 +235,19 @@ class AmplifyBackendClient:
         Status: str = None,
     ) -> ListBackendJobsResponseTypeDef:
         """
-        [Client.list_backend_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.list_backend_jobs)
+        [Client.list_backend_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.list_backend_jobs)
         """
 
     def remove_all_backends(
         self, AppId: str, CleanAmplifyApp: bool = None
     ) -> RemoveAllBackendsResponseTypeDef:
         """
-        [Client.remove_all_backends documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_all_backends)
+        [Client.remove_all_backends documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_all_backends)
         """
 
     def remove_backend_config(self, AppId: str) -> RemoveBackendConfigResponseTypeDef:
         """
-        [Client.remove_backend_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_backend_config)
+        [Client.remove_backend_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_backend_config)
         """
 
     def update_backend_api(
@@ -264,7 +258,7 @@ class AmplifyBackendClient:
         ResourceConfig: "BackendAPIResourceConfigTypeDef" = None,
     ) -> UpdateBackendAPIResponseTypeDef:
         """
-        [Client.update_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_api)
+        [Client.update_backend_api documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_api)
         """
 
     def update_backend_auth(
@@ -275,14 +269,14 @@ class AmplifyBackendClient:
         ResourceName: str,
     ) -> UpdateBackendAuthResponseTypeDef:
         """
-        [Client.update_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_auth)
+        [Client.update_backend_auth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_auth)
         """
 
     def update_backend_config(
         self, AppId: str, LoginAuthConfig: "LoginAuthConfigReqObjTypeDef" = None
     ) -> UpdateBackendConfigResponseTypeDef:
         """
-        [Client.update_backend_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_config)
+        [Client.update_backend_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_config)
         """
 
     def update_backend_job(
@@ -294,12 +288,12 @@ class AmplifyBackendClient:
         Status: str = None,
     ) -> UpdateBackendJobResponseTypeDef:
         """
-        [Client.update_backend_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_job)
+        [Client.update_backend_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_job)
         """
 
     def get_paginator(
-        self, operation_name: Literal["list_backend_jobs"]
+        self, operation_name: ListBackendJobsPaginatorName
     ) -> ListBackendJobsPaginator:
         """
-        [Paginator.ListBackendJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.50/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
+        [Paginator.ListBackendJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
         """
