@@ -12,10 +12,22 @@ Usage::
 import sys
 from typing import List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_amplifybackend.literals import (
+    AdditionalConstraintsElement,
+    AuthResources,
+    DeliveryMethod,
+    MFAMode,
+    MfaTypesElement,
+    Mode,
+    OAuthGrantType,
+    OAuthScopesElement,
+    RequiredSignUpAttributesElement,
+    ResolutionStrategy,
+    Service,
+    SignInMethod,
+    Status,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -92,17 +104,12 @@ BackendAPIAppSyncAuthSettingsTypeDef = TypedDict(
 
 BackendAPIAuthTypeTypeDef = TypedDict(
     "BackendAPIAuthTypeTypeDef",
-    {
-        "Mode": Literal["API_KEY", "AWS_IAM", "AMAZON_COGNITO_USER_POOLS", "OPENID_CONNECT"],
-        "Settings": "BackendAPIAppSyncAuthSettingsTypeDef",
-    },
+    {"Mode": Mode, "Settings": "BackendAPIAppSyncAuthSettingsTypeDef"},
     total=False,
 )
 
 BackendAPIConflictResolutionTypeDef = TypedDict(
-    "BackendAPIConflictResolutionTypeDef",
-    {"ResolutionStrategy": Literal["OPTIMISTIC_CONCURRENCY", "LAMBDA", "AUTOMERGE", "NONE"]},
-    total=False,
+    "BackendAPIConflictResolutionTypeDef", {"ResolutionStrategy": ResolutionStrategy}, total=False
 )
 
 BackendAPIResourceConfigTypeDef = TypedDict(
@@ -146,8 +153,7 @@ class BackendJobRespObjTypeDef(
 
 
 _RequiredCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthForgotPasswordConfigTypeDef",
-    {"DeliveryMethod": Literal["EMAIL", "SMS"]},
+    "_RequiredCreateBackendAuthForgotPasswordConfigTypeDef", {"DeliveryMethod": DeliveryMethod}
 )
 _OptionalCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
     "_OptionalCreateBackendAuthForgotPasswordConfigTypeDef",
@@ -169,7 +175,7 @@ CreateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
 )
 
 _RequiredCreateBackendAuthMFAConfigTypeDef = TypedDict(
-    "_RequiredCreateBackendAuthMFAConfigTypeDef", {"MFAMode": Literal["ON", "OFF", "OPTIONAL"]}
+    "_RequiredCreateBackendAuthMFAConfigTypeDef", {"MFAMode": MFAMode}
 )
 _OptionalCreateBackendAuthMFAConfigTypeDef = TypedDict(
     "_OptionalCreateBackendAuthMFAConfigTypeDef", {"Settings": "SettingsTypeDef"}, total=False
@@ -185,10 +191,8 @@ class CreateBackendAuthMFAConfigTypeDef(
 _RequiredCreateBackendAuthOAuthConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthOAuthConfigTypeDef",
     {
-        "OAuthGrantType": Literal["CODE", "IMPLICIT"],
-        "OAuthScopes": List[
-            Literal["PHONE", "EMAIL", "OPENID", "PROFILE", "AWS_COGNITO_SIGNIN_USER_ADMIN"]
-        ],
+        "OAuthGrantType": OAuthGrantType,
+        "OAuthScopes": List[OAuthScopesElement],
         "RedirectSignInURIs": List[str],
         "RedirectSignOutURIs": List[str],
     },
@@ -211,11 +215,7 @@ _RequiredCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
 )
 _OptionalCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
     "_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef",
-    {
-        "AdditionalConstraints": List[
-            Literal["REQUIRE_DIGIT", "REQUIRE_LOWERCASE", "REQUIRE_SYMBOL", "REQUIRE_UPPERCASE"]
-        ]
-    },
+    {"AdditionalConstraints": List[AdditionalConstraintsElement]},
     total=False,
 )
 
@@ -230,8 +230,8 @@ class CreateBackendAuthPasswordPolicyConfigTypeDef(
 _RequiredCreateBackendAuthResourceConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthResourceConfigTypeDef",
     {
-        "AuthResources": Literal["USER_POOL_ONLY", "IDENTITY_POOL_AND_USER_POOL"],
-        "Service": Literal["COGNITO"],
+        "AuthResources": AuthResources,
+        "Service": Service,
         "UserPoolConfigs": "CreateBackendAuthUserPoolConfigTypeDef",
     },
 )
@@ -251,28 +251,8 @@ class CreateBackendAuthResourceConfigTypeDef(
 _RequiredCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
     "_RequiredCreateBackendAuthUserPoolConfigTypeDef",
     {
-        "RequiredSignUpAttributes": List[
-            Literal[
-                "ADDRESS",
-                "BIRTHDATE",
-                "EMAIL",
-                "FAMILY_NAME",
-                "GENDER",
-                "GIVEN_NAME",
-                "LOCALE",
-                "MIDDLE_NAME",
-                "NAME",
-                "NICKNAME",
-                "PHONE_NUMBER",
-                "PICTURE",
-                "PREFERRED_USERNAME",
-                "PROFILE",
-                "UPDATED_AT",
-                "WEBSITE",
-                "ZONE_INFO",
-            ]
-        ],
-        "SignInMethod": Literal["EMAIL", "EMAIL_AND_PHONE_NUMBER", "PHONE_NUMBER", "USERNAME"],
+        "RequiredSignUpAttributes": List[RequiredSignUpAttributesElement],
+        "SignInMethod": SignInMethod,
         "UserPoolName": str,
     },
 )
@@ -310,7 +290,7 @@ LoginAuthConfigReqObjTypeDef = TypedDict(
 )
 
 SettingsTypeDef = TypedDict(
-    "SettingsTypeDef", {"MfaTypes": List[Literal["SMS", "TOTP"]], "SmsMessage": str}, total=False
+    "SettingsTypeDef", {"MfaTypes": List[MfaTypesElement], "SmsMessage": str}, total=False
 )
 
 SmsSettingsTypeDef = TypedDict("SmsSettingsTypeDef", {"SmsMessage": str}, total=False)
@@ -328,7 +308,7 @@ SocialProviderSettingsTypeDef = TypedDict(
 UpdateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
     "UpdateBackendAuthForgotPasswordConfigTypeDef",
     {
-        "DeliveryMethod": Literal["EMAIL", "SMS"],
+        "DeliveryMethod": DeliveryMethod,
         "EmailSettings": "EmailSettingsTypeDef",
         "SmsSettings": "SmsSettingsTypeDef",
     },
@@ -341,7 +321,7 @@ UpdateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
 
 UpdateBackendAuthMFAConfigTypeDef = TypedDict(
     "UpdateBackendAuthMFAConfigTypeDef",
-    {"MFAMode": Literal["ON", "OFF", "OPTIONAL"], "Settings": "SettingsTypeDef"},
+    {"MFAMode": MFAMode, "Settings": "SettingsTypeDef"},
     total=False,
 )
 
@@ -349,10 +329,8 @@ UpdateBackendAuthOAuthConfigTypeDef = TypedDict(
     "UpdateBackendAuthOAuthConfigTypeDef",
     {
         "DomainPrefix": str,
-        "OAuthGrantType": Literal["CODE", "IMPLICIT"],
-        "OAuthScopes": List[
-            Literal["PHONE", "EMAIL", "OPENID", "PROFILE", "AWS_COGNITO_SIGNIN_USER_ADMIN"]
-        ],
+        "OAuthGrantType": OAuthGrantType,
+        "OAuthScopes": List[OAuthScopesElement],
         "RedirectSignInURIs": List[str],
         "RedirectSignOutURIs": List[str],
         "SocialProviderSettings": "SocialProviderSettingsTypeDef",
@@ -362,12 +340,7 @@ UpdateBackendAuthOAuthConfigTypeDef = TypedDict(
 
 UpdateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
     "UpdateBackendAuthPasswordPolicyConfigTypeDef",
-    {
-        "AdditionalConstraints": List[
-            Literal["REQUIRE_DIGIT", "REQUIRE_LOWERCASE", "REQUIRE_SYMBOL", "REQUIRE_UPPERCASE"]
-        ],
-        "MinimumLength": float,
-    },
+    {"AdditionalConstraints": List[AdditionalConstraintsElement], "MinimumLength": float},
     total=False,
 )
 
@@ -503,9 +476,7 @@ GenerateBackendAPIModelsResponseTypeDef = TypedDict(
 )
 
 GetBackendAPIModelsResponseTypeDef = TypedDict(
-    "GetBackendAPIModelsResponseTypeDef",
-    {"Models": str, "Status": Literal["LATEST", "STALE"]},
-    total=False,
+    "GetBackendAPIModelsResponseTypeDef", {"Models": str, "Status": Status}, total=False
 )
 
 GetBackendAPIResponseTypeDef = TypedDict(
@@ -602,8 +573,8 @@ UpdateBackendAPIResponseTypeDef = TypedDict(
 _RequiredUpdateBackendAuthResourceConfigTypeDef = TypedDict(
     "_RequiredUpdateBackendAuthResourceConfigTypeDef",
     {
-        "AuthResources": Literal["USER_POOL_ONLY", "IDENTITY_POOL_AND_USER_POOL"],
-        "Service": Literal["COGNITO"],
+        "AuthResources": AuthResources,
+        "Service": Service,
         "UserPoolConfigs": "UpdateBackendAuthUserPoolConfigTypeDef",
     },
 )
